/*  DataBrowserP.h

    Private header for  DataBrowser  widget class.

    Copyright (C) 2002-2004  Richard Gooch

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    Richard Gooch may be reached by email at  karma-request@atnf.csiro.au
    The postal address is:
      Richard Gooch, c/o ATNF, P. O. Box 76, Epping, N.S.W., 2121, Australia.
*/

/*

    This include file contains the private class declarations for the
    DataBrowser widget.


    Written by      Richard Gooch   23-NOV-2002

    Last updated by Richard Gooch   14-JUL-2004

*/
#ifndef DataBrowserP__H
#define DataBrowserP__H

#include <X11/IntrinsicP.h>
#include <X11/ShellP.h>
#include <X11/StringDefs.h>

#if !defined(KARMA_DISPDATA_DEF_H) || defined(MAKEDEPEND)
#  include <karma_dispdata_def.h>
#endif

#if !defined(KARMA_LISTW_DEF_H) || defined(MAKEDEPEND)
#  include <karma_listw_def.h>
#endif

#include <Xkw/DataBrowser.h>

struct array_form
{
    Widget                  form;
    Widget                  source_lbl;
    Widget                  objectNdate_lbl;
    Widget                  fu_lbl;
    Widget                  size_lbl;
    Widget                  minmax_lbl;
    Widget                  histogram_btn;
    Widget                  image_mode_menu;
    Widget                  contour_mode_menu;
    Widget                  movie_mode_menu;
    Widget                  profile_mode_menu;
    Widget                  low_clip_txt;
    Widget                  high_clip_txt;
    Widget                  contour_levels_txt;
    Widget                  contour_neg_width_sld;
    Widget                  contour_pos_width_sld;
    Widget                  contour_neg_colour_txt;
    Widget                  contour_pos_colour_txt;
    Widget                  renzogram_levels_txt;
    Widget                  renzogram_channels_txt;
    Widget                  profile_dark_colour_txt;
    Widget                  profile_light_colour_txt;
};

struct overlay_form
{
    Widget                  form;
    Widget                  source_lbl;
    Widget                  active_tgl;
};

typedef struct _DataBrowserPart
{
    /*  Public resources  */
    Bool                    popupFirstDataBrowser;
    Bool                    createAtInit;
    /*  Private resources  */
    flag                    user_popped_up;
    int                     dataclass_mode;
    struct blinkstate       *my_blinkstate;
    struct blinkstate       *current_blinkstate;
    flag                    active_mode;
    unsigned int            selected;
    unsigned int            *num_entries;
    Widget                  main_form;
    Widget                  destroy_btn;
    Widget                  active_btn;
    Widget                  browser_mode_menu;
    Widget                  list_widget;
    KListWidget             listw;
    Widget                  viewdatasets;
    Widget                  animatecontrol;
    Widget                  image_display_widget;
    Pixel                   image_display_bg;
    struct array_form       array;
    struct overlay_form     overlay;
    void                    (*show_details) (DataBrowserWidget w);
    void                    (*process_event) (DataBrowserWidget w, int index,
					      int event_code,
					      unsigned long mask);
} DataBrowserPart, *DataBrowserPartPtr;

typedef struct _DataBrowserRec
{
    CorePart core;
    CompositePart composite;
    ShellPart shell;
    WMShellPart wm;
    VendorShellPart vendor;
    TopLevelShellPart topLevel;
    DataBrowserPart dataBrowser;
} DataBrowserRec, *DataBrowserPtr;

typedef struct _DataBrowserClassPart
{
    int empty;
} DataBrowserClassPart;

typedef struct _DataBrowserClassRec
{
    CoreClassPart core_class;	
    CompositeClassPart composite_class;
    ShellClassPart shell_class;
    WMShellClassPart wm_shell_class;
    VendorShellClassPart vendor_shell_class;
    TopLevelShellClassPart top_level_shell_class;
    DataBrowserClassPart dataBrowser_class;
} DataBrowserClassRec, *DataBrowserClassPtr;

extern DataBrowserClassRec dataBrowserClassRec;

#endif
