/*  ViewDatasets.h

    Private header for  ViewDatasets  widget class.

    Copyright (C) 2002-2003  Richard Gooch

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    Richard Gooch may be reached by email at  karma-request@atnf.csiro.au
    The postal address is:
      Richard Gooch, c/o ATNF, P. O. Box 76, Epping, N.S.W., 2121, Australia.
*/

/*

    This include file contains the private class declarations for the
  ViewDatasets widget.


    Written by      Richard Gooch   5-DEC-2002

    Last updated by Richard Gooch   14-JUN-2003

*/
#ifndef ViewDatasetsP__H
#define ViewDatasetsP__H

#include <X11/IntrinsicP.h>
#include <X11/ShellP.h>
#include <X11/StringDefs.h>

#include <Xkw/ViewDatasets.h>
#include <karma_contour_def.h>

struct cursor_tracking_struct
{
    flag           listen;
    flag           last_was_inside;
    KCallbackFunc  listen_callback;
};

struct vimage_handle
{
    ViewableImage vimage;
    KCallbackFunc cbk;
};

typedef struct _ViewDatasetsPart
{
    /*  Public resources  */
    Bool           verbose;
    String         wmtitle;
    XtCallbackList cursorCallback;
    /*  Private resources  */
    Widget image_display;
    Widget animatepopup;
    Widget trace_winpopup;
    unsigned int slice;
    unsigned int profile_dir;
    unsigned int profile_mode;
    unsigned int last_event_code;
    Widget profile_dir_menu;
    Widget title_txt;
    Widget auto_title_tgl;
    Widget show_beam_tgl;
    Widget show_beam_name_tgl;
    Widget middle_zoom_tgl;
    Widget right_zoom_tgl;
    Widget show_profile_marker_tgl;
    Widget scatter_plot_shell;
    Widget scatter_plot_auto_tgl;
    Widget scatter_plot_track_lbl2;
    KWorldCanvas trace_canvas;
    KPixCanvasRefreshArea main_marker_area;  /*  For marker on main canvas  */
    KWorldCanvas scatter_plot_canvas;
    KScatterPlot scatter_plot;
    KWorldCanvasLimits scatter_plot_limits;
    unsigned int scatter_plot_xstart;                      /*  For x_vimage  */
    unsigned int scatter_plot_xlen;                        /*  For x_vimage  */
    unsigned int scatter_plot_ystart;                      /*  For x_vimage  */
    unsigned int scatter_plot_ylen;                        /*  For x_vimage  */
    struct vimage_handle scatter_plot_x_handle;
    struct vimage_handle scatter_plot_y_handle;
    KPixCanvasRefreshArea scatter_plot_marker_area;/* Marker on scatplot cnv */
    double scale, offset;   /*  Used when loading to preserve scaled iscale  */
    double beam_xpos;
    double beam_ypos;
    struct cursor_tracking_struct cursor_tracking;
} ViewDatasetsPart, *ViewDatasetsPartPtr;

typedef struct _ViewDatasetsRec
{
    CorePart core;
    CompositePart composite;
    ShellPart shell;
    WMShellPart wm;
    VendorShellPart vendor;
#ifdef USE_TRANSIENT
    TransientShellPart transient;
#else
    TopLevelShellPart topLevel;
#endif
    ViewDatasetsPart viewDatasets;
} ViewDatasetsRec, *ViewDatasetsPtr;

typedef struct _ViewDatasetsClassPart
{
    int empty;
} ViewDatasetsClassPart;

typedef struct _ViewDatasetsClassRec
{
    CoreClassPart core_class;	
    CompositeClassPart composite_class;
    ShellClassPart shell_class;
    WMShellClassPart wm_shell_class;
    VendorShellClassPart vendor_shell_class;
#ifdef USE_TRANSIENT
    TransientShellClassPart transient_shell_class;
#else
    TopLevelShellClassPart top_level_shell_class;
#endif
    ViewDatasetsClassPart viewDatasets_class;
} ViewDatasetsClassRec, *ViewDatasetsClassPtr;

extern ViewDatasetsClassRec viewDatasetsClassRec;

#endif
