/*  karma_dispdata.h

    Header for  dispdata_  package.

    Copyright (C) 2002-2004  Richard Gooch

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    Richard Gooch may be reached by email at  karma-request@atnf.csiro.au
    The postal address is:
      Richard Gooch, c/o ATNF, P. O. Box 76, Epping, N.S.W., 2121, Australia.
*/

/*

    This include file contains all the definitions and function declarations
  needed to interface to the dispdata_ routines in the Karma library.


    Written by      Richard Gooch   10-NOV-2002

    Last updated by Richard Gooch   18-JUL-2004

*/

#if !defined(KARMA_H) || defined(MAKEDEPEND)
#  include <karma.h>
#endif

#if !defined(KARMA_DISPDATA_DEF_H) || defined(MAKEDEPEND)
#  include <karma_dispdata_def.h>
#endif

#if !defined(KARMA_OVERLAY_DEF_H) || defined(MAKEDEPEND)
#  include <karma_overlay_def.h>
#endif

#if !defined(KARMA_C_DEF_H) || defined(MAKEDEPEND)
#  include <karma_c_def.h>
#endif

#ifndef KARMA_DISPDATA_H
#define KARMA_DISPDATA_H


#define KDISPLAYDATA_SLICE_DIRECTION_XY                   0
#define KDISPLAYDATA_SLICE_DIRECTION_XZ                   1
#define KDISPLAYDATA_SLICE_DIRECTION_ZY                   2
#define KDISPLAYDATA_NUM_SLICE_DIRECTIONS                 3
extern char *dispdata_slice_choices[KDISPLAYDATA_NUM_SLICE_DIRECTIONS];

#define KDISPLAYDATA_CONTOUR_OFF                          0
#define KDISPLAYDATA_CONTOUR_NORMAL                       1
#define KDISPLAYDATA_CONTOUR_RENZOGRAM                    2

#define KDISPLAYDATA_PROFILE_MODE_NONE                    0
#define KDISPLAYDATA_PROFILE_MODE_LINE                    1
#define KDISPLAYDATA_PROFILE_MODE_BOX_SUM                 2
#define KDISPLAYDATA_PROFILE_MODE_BOX_AVERAGE             3
#define KDISPLAYDATA_PROFILE_MODE_RADIAL                  4
#define KDISPLAYDATA_PROFILE_MODE_RADIAL_GAUSS            5
#define KDISPLAYDATA_PROFILE_MODE_AZIMUTHAL_AVERAGE       6
#define KDISPLAYDATA_PROFILE_MODE_BOXED_HORIZONTAL        7
#define KDISPLAYDATA_PROFILE_MODE_BOXED_VERTICAL          8
#define KDISPLAYDATA_NUM_PROFILE_MODE_CHOICES             9
extern char
    *dispdata_profile_mode_choices[KDISPLAYDATA_NUM_PROFILE_MODE_CHOICES];

#define KDISPLAYDATA_PROFILE_DIR_Z                        0
#define KDISPLAYDATA_PROFILE_DIR_Y                        1
#define KDISPLAYDATA_PROFILE_DIR_X                        2
#define KDISPLAYDATA_NUM_PROFILE_DIR_CHOICES              3
extern char
    *dispdata_profile_dir_choices[KDISPLAYDATA_NUM_PROFILE_DIR_CHOICES];

#define KDISPLAYDATA_CLIP_MODE_CHANGE_IMAGE_AND_PROFILE   0
#define KDISPLAYDATA_CLIP_MODE_CHANGE_IMAGE_ONLY          1
#define KDISPLAYDATA_CLIP_MODE_CHANGE_PROFILE_ONLY        2
#define KDISPLAYDATA_CLIP_MODE_CHANGE_BOTH_LATER          3
#define KDISPLAYDATA_NUM_CLIP_MODE_CHOICES                4
extern char
    *dispdata_clip_mode_choices[KDISPLAYDATA_NUM_CLIP_MODE_CHOICES];


/*  Attributes for data objects  */

#define KDISPLAYDATA_DATA_ATT_END                         0
#define KDISPLAYDATA_DATA_ATT_DOMAIN                      1
#define KDISPLAYDATA_DATA_ATT_NAME                        2
#define KDISPLAYDATA_DATA_ATT_DIRECTORY                   3
#define KDISPLAYDATA_DATA_ATT_REPLACE                     4
/*  Array-specific attributes: read/write attributes  */
#define KDISPLAYDATA_DATA_ATT_RAW_LOWER_CLIP            101
#define KDISPLAYDATA_DATA_ATT_RAW_UPPER_CLIP            102
#define KDISPLAYDATA_DATA_ATT_SCALED_LOWER_CLIP         103
#define KDISPLAYDATA_DATA_ATT_SCALED_UPPER_CLIP         104
#define KDISPLAYDATA_DATA_ATT_CONTOUR_NEG_COLOUR        105
#define KDISPLAYDATA_DATA_ATT_CONTOUR_POS_COLOUR        106
#define KDISPLAYDATA_DATA_ATT_CONTOUR_NEG_LINEWIDTH     107
#define KDISPLAYDATA_DATA_ATT_CONTOUR_POS_LINEWIDTH     108
#define KDISPLAYDATA_DATA_ATT_CONTOUR_LEVELS            109
#define KDISPLAYDATA_DATA_ATT_RENZOGRAM_LEVELS          110
#define KDISPLAYDATA_DATA_ATT_RENZOGRAM_CHANNELS        111
#define KDISPLAYDATA_DATA_ATT_PROFILE_DARK_COLOUR       112
#define KDISPLAYDATA_DATA_ATT_PROFILE_LIGHT_COLOUR      113
/*  Array-specific attributes: read-only attributes  */
#define KDISPLAYDATA_DATA_ATT_FRAME_NUMBER              150
#define KDISPLAYDATA_DATA_ATT_NUM_FRAMES                151
#define KDISPLAYDATA_DATA_ATT_DIRECTION_FOR_FRAME       152
#define KDISPLAYDATA_DATA_ATT_OBJECT                    153
#define KDISPLAYDATA_DATA_ATT_PSEUDO_ARRAY              154
#define KDISPLAYDATA_DATA_ATT_RED_ARRAY                 155
#define KDISPLAYDATA_DATA_ATT_GREEN_ARRAY               156
#define KDISPLAYDATA_DATA_ATT_BLUE_ARRAY                157
#define KDISPLAYDATA_DATA_ATT_RAW_MINIMUM               158
#define KDISPLAYDATA_DATA_ATT_RAW_MAXIMUM               159
#define KDISPLAYDATA_DATA_ATT_SCALED_MINIMUM            160
#define KDISPLAYDATA_DATA_ATT_SCALED_MAXIMUM            161


/*  Attributes for blinkentry objects  */

#define KDISPLAYDATA_BLINKENTRY_ATT_END                   0
/*  Array-specific attributes: read/write attributes  */
#define KDISPLAYDATA_BLINKENTRY_ATT_IMAGE              1000
#define KDISPLAYDATA_BLINKENTRY_ATT_CONTOUR_MODE       1001
#define KDISPLAYDATA_BLINKENTRY_ATT_MOVIE_MASTER       1002
#define KDISPLAYDATA_BLINKENTRY_ATT_MOVIE_SLAVE        1003
#define KDISPLAYDATA_BLINKENTRY_ATT_PROFILE_MASTER     1004
#define KDISPLAYDATA_BLINKENTRY_ATT_PROFILE_SLAVE      1005
/*  Array-specific attributes: read-only attributes  */
#define KDISPLAYDATA_BLINKENTRY_ATT_VIMAGE             1050
/*  Overlay-specific attributes: read/write attributes  */
#define KDISPLAYDATA_BLINKENTRY_ATT_ACTIVE             1100


/*  Attributes for window objects  */

#define KDISPLAYDATA_WINDOW_ATT_END                       0
/*  Array-specific attributes: read/write attributes  */
#define KDISPLAYDATA_WINDOW_ATT_SLICE_DIRECTION        2000
#define KDISPLAYDATA_WINDOW_ATT_SET_ISCALE             2001
#define KDISPLAYDATA_WINDOW_ATT_FRAME_NUMBER           2002
#define KDISPLAYDATA_WINDOW_ATT_PROFILE_CANVAS         2003
#define KDISPLAYDATA_WINDOW_ATT_PROFILE_MODE           2004
#define KDISPLAYDATA_WINDOW_ATT_PROFILE_DIRECTION      2005
#define KDISPLAYDATA_WINDOW_ATT_AUTO_TITLE             2006
#define KDISPLAYDATA_WINDOW_ATT_SHOW_MARKER_IN_PROFILE 2007
/*  Array-specific attributes: read-only attributes  */
#define KDISPLAYDATA_WINDOW_ATT_IMAGE                  2050
#define KDISPLAYDATA_WINDOW_ATT_MOVIE_MASTER           2051
#define KDISPLAYDATA_WINDOW_ATT_PROFILE_MASTER         2052


/*  Attributes for dataclasses (i.e. global)  */
#define KDISPLAYDATA_CLASS_ATT_END                        0
#define KDISPLAYDATA_CLASS_ATT_CURRENTLY_CREATING         1
/*  Array dataclass-specific attributes  */
#define KDISPLAYDATA_CLASS_ATT_CLIP_MODE               3000
#define KDISPLAYDATA_CLASS_ATT_SLAVE_PROFILE_H_ZOOM    3001


/*  File:  main.c  */
EXTERN_FUNCTION (void dispdata_init, (void) );
EXTERN_FUNCTION (unsigned int dispdata_get_classlist,
		 (KDisplayDataClass **classes, char ***names) );
EXTERN_FUNCTION (KCallbackFunc dispdata_register_data_create_func,
		 (KDisplayDataClass dataclass,
		  void (*func) (void *info, KDisplayDataObject data),
		  void *info) );
EXTERN_FUNCTION (KCallbackFunc dispdata_register_data_destroy_func,
		 (KDisplayDataClass dataclass, void (*func) (void *info),
		  void *info) );
EXTERN_FUNCTION (KCallbackFunc dispdata_register_dataobject_destroy_func,
		 (KDisplayDataObject dataobject, void (*func) (void *info),
		  void *info) );
EXTERN_FUNCTION (void dispdata_set_dataclass_attributes,
		 (KDisplayDataClass dataclass, ...) );
EXTERN_FUNCTION (void dispdata_get_dataclass_attributes,
		 (KDisplayDataClass dataclass, ...) );
EXTERN_FUNCTION (KDisplayDataWindow dispdata_create_window,
		 (KDisplayDataCanvas pc, KDisplayDataCanvas rgb,
		  void (*show_canvas) (void *info, KWorldCanvas canvas),
		  void *info) );
EXTERN_FUNCTION (void dispdata_destroy_window, (KDisplayDataWindow window) );
EXTERN_FUNCTION (KCallbackFunc dispdata_register_window_destroy_func,
		 (KDisplayDataWindow window, void (*func) (), void *info) );
EXTERN_FUNCTION (void dispdata_set_window_attributes,
		 (KDisplayDataWindow window, ...) );
EXTERN_FUNCTION (void dispdata_get_window_attributes,
		 (KDisplayDataWindow window, ...) );
EXTERN_FUNCTION (unsigned int dispdata_get_num_windows, () );
EXTERN_FUNCTION (void dispdata_refresh_window,
		 (KDisplayDataWindow window, KWorldCanvas canvas) );
EXTERN_FUNCTION (unsigned int dispdata_get_num_blinkstates,
		 (KDisplayDataWindow window) );
EXTERN_FUNCTION (KDisplayDataBlinkState dispdata_get_active_blinkstate,
		 (KDisplayDataWindow window, void **info) );
EXTERN_FUNCTION (KDisplayDataWindow dispdata_get_first_window, (void **info) );
EXTERN_FUNCTION (KDisplayDataWindow dispdata_get_prev_window,
		 (KDisplayDataWindow window, flag circular, void **info) );
EXTERN_FUNCTION (KDisplayDataWindow dispdata_get_next_window,
		 (KDisplayDataWindow window, flag circular, void **info) );
EXTERN_FUNCTION (unsigned int dispdata_get_window_index,
		 (KDisplayDataWindow window) );
EXTERN_FUNCTION (KCallbackFunc dispdata_register_window_renumber_func,
		 (KDisplayDataWindow window, void (*func) (), void *info) );
EXTERN_FUNCTION (KDisplayDataObject dispdata_create_dataobject,
		 (KDisplayDataClass dataclass, CONST char *domain,
		  CONST char *name, void *data) );
EXTERN_FUNCTION (void dispdata_destroy_dataobject,
		 (KDisplayDataObject dataobject) );
EXTERN_FUNCTION (void *dispdata_get_dataobject_subclass,
		 (KDisplayDataObject dataobject,KDisplayDataClass dataclass) );
EXTERN_FUNCTION (void dispdata_set_data_attributes,
		 (KDisplayDataObject dataobject, ...) );
EXTERN_FUNCTION (void dispdata_get_data_attributes,
		 (KDisplayDataObject dataobject, ...) );
EXTERN_FUNCTION (void dispdata_associate_data_object,
		 (KDisplayDataObject dataobject, CONST char *name,
		  void (*destroy_func) (void *object),
		  void *object) );
EXTERN_FUNCTION (void *dispdata_get_associated_data_object,
		 (KDisplayDataObject dataobject, CONST char *name) );
EXTERN_FUNCTION (KDisplayDataObject dispdata_get_first_dataobject,
		 (KDisplayDataClass dataclass) );
EXTERN_FUNCTION (KDisplayDataObject dispdata_get_next_dataobject,
		 (KDisplayDataObject dataobject) );
EXTERN_FUNCTION (KDisplayDataBlinkState dispdata_create_blinkstate,
		 (KDisplayDataWindow window,
		  void (*active_change) (void *info, flag active),
		  void *info) );
EXTERN_FUNCTION (void dispdata_destroy_blinkstate,
		 (KDisplayDataBlinkState blinkstate) );
EXTERN_FUNCTION (KDisplayDataClassBlinkState dispdata_get_blinkstate_class,
		 (KDisplayDataBlinkState blinkstate,
		  KDisplayDataClass dataclass) );
EXTERN_FUNCTION (void dispdata_activate_blinkstate,
		 (KDisplayDataBlinkState blinkstate) );
EXTERN_FUNCTION (flag dispdata_test_blinkstate_active,
		 (KDisplayDataBlinkState blinkstate) );
EXTERN_FUNCTION (unsigned int dispdata_get_blinkstate_index,
		 (KDisplayDataBlinkState blinkstate) );
EXTERN_FUNCTION (void dispdata_copy_blinkstate,
		 (KDisplayDataBlinkState dest,KDisplayDataBlinkState source) );
EXTERN_FUNCTION (void dispdata_refresh_blinkstate,
		 (KDisplayDataBlinkState blinkstate) );
EXTERN_FUNCTION (void *dispdata_get_blinkstate_info,
		 (KDisplayDataBlinkState blinkstate) );
EXTERN_FUNCTION (void dispdata_register_blinkstate_funcs,
		 (KDisplayDataClassBlinkState blinkstate,
		  void (*refresh_func) (void *info,
					KDisplayDataClass dataclass),
		  void *(*create_blinkentry) (void *info,
					      KDisplayDataBlinkEntry be),
		  void (*destroy_blinkentry) (void *info),
		  void (*copy_blinkentry) (void *dest, void *source),
		  void *info) );
EXTERN_FUNCTION (KDisplayDataBlinkState dispdata_get_first_blinkstate,
		 (KDisplayDataWindow window, void **info) );
EXTERN_FUNCTION (KDisplayDataBlinkState dispdata_get_last_blinkstate,
		 (KDisplayDataWindow window, void **info) );
EXTERN_FUNCTION (KDisplayDataBlinkState dispdata_get_prev_blinkstate,
		 (KDisplayDataBlinkState blinkstate, flag circular,
		  void **info) );
EXTERN_FUNCTION (KDisplayDataBlinkState dispdata_get_next_blinkstate,
		 (KDisplayDataBlinkState blinkstate, flag circular,
		  void **info) );
EXTERN_FUNCTION (KDisplayDataWindow dispdata_get_window_from_blinkstate,
		 (KDisplayDataBlinkState blinkstate) );
EXTERN_FUNCTION (CONST char **dispdata_get_namelist,
		 (KDisplayDataClass dataclass, unsigned int *num_entries,
		  unsigned int *num_chars) );
EXTERN_FUNCTION (char **dispdata_regenerate_namelist,
		 (KDisplayDataClass dataclass,
		  KDisplayDataPrivateNameList *namelist_ptr,
		  unsigned int num_reserved, unsigned int *num_entries,
		  KDisplayDataObject **dataobjects,
		  flag (*filter_func) (void *info,
				       KDisplayDataObject dataobject),
		  void *info) );
EXTERN_FUNCTION (void dispdata_free_namelist,
		 (KDisplayDataPrivateNameList namelist) );
EXTERN_FUNCTION (CONST KDisplayDataObject *dispdata_get_objectlist,
		 (KDisplayDataClass dataclass, unsigned int *num_entries) );
EXTERN_FUNCTION (KDisplayDataBlinkEntry dispdata_get_first_blinkentry,
		 (KDisplayDataClassBlinkState class_blinkstate) );
EXTERN_FUNCTION (KDisplayDataBlinkEntry dispdata_get_next_blinkentry,
		 (KDisplayDataBlinkEntry blinkentry) );
EXTERN_FUNCTION (void *dispdata_get_blinkentry_info,
		 (KDisplayDataBlinkEntry blinkentry) );
EXTERN_FUNCTION (void dispdata_set_blinkentry_attributes,
		 (KDisplayDataBlinkEntry blinkentry, ...) );
EXTERN_FUNCTION (void dispdata_get_blinkentry_attributes,
		 (KDisplayDataBlinkEntry blinkentry, ...) );
EXTERN_FUNCTION (CONST KDisplayDataBlinkEntry *dispdata_regenerate_blinkentry_list,
		 (KDisplayDataClassBlinkState blinkstate,
		  unsigned int *num_entries) );
EXTERN_FUNCTION (KDisplayDataObject dispdata_get_dataobject_from_blinkentry,
		 (KDisplayDataBlinkEntry blinkentry) );


/*  File:  array.c  */
EXTERN_FUNCTION (KDisplayDataClass dispdata_array_create_dataclass, (void) );
EXTERN_FUNCTION (void dispdata_array_clone_data,
		 (KDisplayDataObject dataobject) );
EXTERN_FUNCTION (KCallbackFunc dispdata_array_register_irange_change_func,
		 (KDisplayDataObject dataobject,
		  void (*func) (KDisplayDataObject dataobject, void *info),
		  void *info) );
EXTERN_FUNCTION (flag dispdata_array_convert_3coord,
		 (KDisplayDataObject dataobject, KDisplayDataWindow window,
		  double *x, double *y, double *z, double h, double v) );


/*  File:  overlay.c  */
EXTERN_FUNCTION (KDisplayDataClass dispdata_overlay_create_dataclass, (void) );
EXTERN_FUNCTION (KDisplayDataObject dispdata_overlay_create_dataobject,
		 (KOverlayList olist, CONST char *domain, CONST char *name) );


#endif /*  KARMA_DISPDATA_H  */
